package com.flyer.foster.controller.app;

import com.flyer.foster.dto.app.AppFosterRecordAddDTO;
import com.flyer.foster.entity.FosterRecord;
import com.flyer.foster.pojo.StpAppUtil;
import com.flyer.foster.service.IFosterRecordService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 领养记录
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/app/foster-record")
public class AppFosterRecordController {

    @Autowired
    private IFosterRecordService iFosterRecordService;

    /**
     * 根据果园id查询领养记录
     * @return
     */
    @GetMapping("/list/{gardenId}")
    public R list(@PathVariable Integer gardenId) {
        String appUserId = StpAppUtil.getLoginId().toString();
        List<FosterRecord> res = iFosterRecordService.lambdaQuery().
                eq(FosterRecord::getAppUserId, appUserId)
                .eq(FosterRecord::getGardenId, gardenId)
                .list();
        return R.ok().result(res);
    }

    /**
     * 确认领养
     *
     * @return
     */
    @PostMapping("")
    public R addFosterRecord(@Valid @RequestBody AppFosterRecordAddDTO addDTO) {
        return R.ok().result(iFosterRecordService.addFosterRecord(addDTO));
    }
}
