package com.flyer.foster.controller.app;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.AreaRespDTO;
import com.flyer.foster.dto.app.AppTreePosterContentAddDTO;
import com.flyer.foster.dto.app.AppTreePosterContentQueryDTO;
import com.flyer.foster.dto.app.AppTreePosterContentRespDTO;
import com.flyer.foster.dto.app.AppTreePosterContentUpdateDTO;
import com.flyer.foster.entity.TreePosterContent;
import com.flyer.foster.service.ITreePosterContentService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * 小程序果树海报悄悄话
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/app/tree-poster-content")
public class AppTreePosterContentController {
    @Autowired
    private ITreePosterContentService iTreePosterContentService;

    /**
     * 海报悄悄话列表-分页（小程序）
     *
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, AppTreePosterContentQueryDTO queryDTO) {
        IPage<TreePosterContent> page = new Page<>(current, size);
        return R.ok().result(iTreePosterContentService.getPageList(page, queryDTO));
    }

    /**
     * 我的问候列表（小程序）
     * @param queryDTO
     * @return
     */
    @GetMapping("/list")
    public R getList(AppTreePosterContentQueryDTO queryDTO) {
        return R.ok().result(iTreePosterContentService.getList(queryDTO));
    }

    /**
     * 新增果树海报悄悄话（小程序）
     *
     * @param addDTO
     * @return
     */
    @PostMapping("")
    public R addTreePosterContent(@Valid @RequestBody AppTreePosterContentAddDTO addDTO) {
        return R.ok().result(iTreePosterContentService.addTreePosterContent(addDTO));
    }

    /**
     * 修改海报悄悄话状态（小程序）
     *
     * @param treePosterContentId
     * @param updateDTO
     * @return
     */
    @PutMapping("/{treePosterContentId}")
    public R updateTreePosterContent(@PathVariable Integer treePosterContentId, @RequestBody AppTreePosterContentUpdateDTO updateDTO) {
        updateDTO.setId(treePosterContentId);
        return R.ok().result(iTreePosterContentService.updateTreePosterContent(treePosterContentId, updateDTO));
    }
}
