package com.flyer.foster.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.conditions.update.LambdaUpdateChainWrapper;
import com.flyer.exception.BusinessException;
import com.flyer.foster.dto.AreaAddDTO;
import com.flyer.foster.dto.AreaRespDTO;
import com.flyer.foster.dto.AreaQueryDTO;
import com.flyer.foster.dto.AreaUpdateDTO;
import com.flyer.foster.entity.Area;
import com.flyer.foster.mapper.IAreaMapper;
import com.flyer.foster.service.IAreaService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 区域 服务实现类
 * </p>
 *
 * @author flyer
 * @since 2024-05-09
 */
@Service
public class AreaServiceImpl extends ServiceImpl<IAreaMapper, Area> implements IAreaService {
    @Override
    public IPage<AreaRespDTO> getPageList(IPage<AreaRespDTO> page, AreaQueryDTO queryDTO) {
        return baseMapper.getPageList(page, queryDTO);
    }

    @Transactional
    @Override
    public boolean addArea(List<AreaAddDTO> addDTOList) {
        Area area = new Area();
        for (AreaAddDTO addDTO : addDTOList) {
            BeanUtil.copyProperties(addDTO, area);
            if (area.getId() == null) {
                this.save(area);
            } else {
                this.lambdaUpdate()
                        .set(Area::getName, addDTO.getName())
                        .set(Area::getGardenId, addDTO.getGardenId())
                        .set(Area::getWkt, addDTO.getWkt())
                        .set(Area::getStatus, addDTO.getStatus())
                        .eq(Area::getId, addDTO.getId())
                        .update();
            }
        }
        return true;
    }

    @Transactional
    @Override
    public boolean deleteByIdList(List<Integer> idList) {
        return baseMapper.deleteByIdList(idList);
    }

    @Transactional
    @Override
    public boolean updateArea(AreaUpdateDTO updateDTO) {
        Area area = baseMapper.selectById(updateDTO.getId());
        if (area == null) {
            throw new BusinessException("无效的区域id");
        }
        return this.lambdaUpdate()
                .set(Area::getName, updateDTO.getName())
                .set(Area::getGardenId, updateDTO.getGardenId())
                .set(Area::getWkt, updateDTO.getWkt())
                .set(Area::getStatus, updateDTO.getStatus())
                .eq(Area::getId, updateDTO.getId())
                .update();
    }
}
