package com.flyer.foster.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.PosterLibQueryDTO;
import com.flyer.foster.dto.PosterLibRespDTO;
import com.flyer.foster.dto.app.AppPosterLibQueryDTO;
import com.flyer.foster.dto.app.AppPosterLibRespDTO;
import com.flyer.foster.entity.PosterLib;
import com.flyer.foster.mapper.IPosterLibMapper;
import com.flyer.foster.service.IPosterLibService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 海报库 服务实现类
 * </p>
 *
 * @author flyer
 * @since 2024-05-09
 */
@Service
public class PosterLibServiceImpl extends ServiceImpl<IPosterLibMapper, PosterLib> implements IPosterLibService {

    @Override
    public boolean deleteByIdList(List<Integer> idList) {
        return baseMapper.deleteByIdList(idList);
    }

    @Override
    public IPage<PosterLibRespDTO> getPageList(IPage<PosterLib> page, PosterLibQueryDTO queryDTO) {
        IPage<PosterLibRespDTO> pageResult = new Page<>(page.getCurrent(), page.getSize());

        IPage<PosterLib> pageInfo = this.lambdaQuery()
                .like(StrUtil.isNotBlank(queryDTO.getName()), PosterLib::getName, queryDTO.getName())
                .page(page);
        List<PosterLibRespDTO> list = new ArrayList<>();
        PosterLibRespDTO posterLibRespDTO;
        for (PosterLib posterLib : pageInfo.getRecords()) {
            posterLibRespDTO = new PosterLibRespDTO();
            BeanUtil.copyProperties(posterLib, posterLibRespDTO);
            list.add(posterLibRespDTO);
        }
        pageResult.setRecords(list);
        pageResult.setTotal(pageInfo.getTotal());
        return pageResult;
    }

    @Override
    public AppPosterLibRespDTO getLatestPoster(AppPosterLibQueryDTO queryDTO) {
        LocalDateTime now = LocalDateTime.now();
        PosterLib posterLib = this.lambdaQuery()
                .le(PosterLib::getStartTime, now)
                .ge(PosterLib::getEndTime, now)
                .orderByDesc(PosterLib::getId)
                .last("limit 1")
                .one();
        AppPosterLibRespDTO respDTO = new AppPosterLibRespDTO();
        BeanUtil.copyProperties(posterLib, respDTO);
        return respDTO;
    }
}
