package com.flyer.foster.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.PosterLibRespDTO;
import com.flyer.foster.dto.app.AppTreePosterContentAddDTO;
import com.flyer.foster.dto.app.AppTreePosterContentQueryDTO;
import com.flyer.foster.dto.app.AppTreePosterContentRespDTO;
import com.flyer.foster.dto.app.AppTreePosterContentUpdateDTO;
import com.flyer.foster.entity.PosterLib;
import com.flyer.foster.entity.TreePosterContent;
import com.flyer.foster.entity.Whisper;
import com.flyer.foster.mapper.ITreePosterContentMapper;
import com.flyer.foster.pojo.StpAppUtil;
import com.flyer.foster.service.IPosterLibService;
import com.flyer.foster.service.ITreePosterContentService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.flyer.foster.service.IWhisperService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 果树海报悄悄话 服务实现类
 * </p>
 *
 * @author flyer
 * @since 2024-05-09
 */
@Service
public class TreePosterContentServiceImpl extends ServiceImpl<ITreePosterContentMapper, TreePosterContent> implements ITreePosterContentService {

    @Autowired
    private IPosterLibService iPosterLibService;

    @Transactional
    @Override
    public AppTreePosterContentRespDTO addTreePosterContent(AppTreePosterContentAddDTO addDTO) {
        int tenantId = StpAppUtil.getTokenSession().getInt("tenantId");
        AppTreePosterContentRespDTO respDTO = new AppTreePosterContentRespDTO();
        LocalDateTime now = LocalDateTime.now();
        // 1.获取海报，取最新一张
        PosterLib posterLib = iPosterLibService.lambdaQuery()
                .le(PosterLib::getStartTime, now)
                .ge(PosterLib::getEndTime, now)
                .orderByDesc(PosterLib::getId)
                .last("limit 1")
                .one();

        if (posterLib != null) {
            // 查询该时间段是否已经插入海报悄悄话
            TreePosterContent treePosterContent = this.lambdaQuery().eq(TreePosterContent::getPosterLibId, posterLib.getId()).one();
            if (treePosterContent == null) {
                // 2.获取悄悄话，取最新一条记录
                treePosterContent = new TreePosterContent();
                BeanUtil.copyProperties(addDTO, treePosterContent);
                treePosterContent.setTenantId(tenantId);
                treePosterContent.setPosterLibId(posterLib.getId());
                treePosterContent.setPosterUrl(posterLib.getUrl());
                treePosterContent.setContent(posterLib.getContent());
                treePosterContent.setCreatedBy("kelei");
                treePosterContent.setCreatedTime(now);
                treePosterContent.setUpdatedBy("kelei");
                treePosterContent.setUpdatedTime(now);
                treePosterContent.setStatus(1);
                // 新增
                this.save(treePosterContent);
            }
            BeanUtil.copyProperties(treePosterContent, respDTO);
        }
        return respDTO;
    }

    @Override
    public boolean updateTreePosterContent(Integer treePosterContentId, AppTreePosterContentUpdateDTO updateDTO) {
        return this.lambdaUpdate()
                .set(TreePosterContent::getStatus, updateDTO.getStatus())
                .eq(TreePosterContent::getId, updateDTO.getId())
                .update();
    }

    @Override
    public IPage<AppTreePosterContentRespDTO> getPageList(IPage<TreePosterContent> page, AppTreePosterContentQueryDTO queryDTO) {
        IPage<AppTreePosterContentRespDTO> pageResult = new Page<>(page.getCurrent(), page.getSize());

        IPage<TreePosterContent> pageInfo = this.lambdaQuery()
                .eq(TreePosterContent::getAppUserId, queryDTO.getAppUserId())
                .eq(TreePosterContent::getTreeId, queryDTO.getTreeId())
                .page(page);
        List<AppTreePosterContentRespDTO> list = new ArrayList<>();
        AppTreePosterContentRespDTO respDTO;
        for (TreePosterContent record : pageInfo.getRecords()) {
            respDTO = new AppTreePosterContentRespDTO();
            BeanUtil.copyProperties(record, respDTO);
            list.add(respDTO);
        }
        pageResult.setRecords(list);
        pageResult.setTotal(pageInfo.getTotal());
        return pageResult;
    }

    @Override
    public List<AppTreePosterContentRespDTO> getList(AppTreePosterContentQueryDTO queryDTO) {
        List<AppTreePosterContentRespDTO> list = new ArrayList<>();
        AppTreePosterContentRespDTO respDTO;

        // 当天最小时间
        LocalDateTime min = LocalDateTime.of(LocalDate.from(LocalDateTime.now()), LocalDateTime.MIN.toLocalTime());
        // 当天最大时间
        LocalDateTime max = LocalDateTime.of(LocalDate.from(LocalDateTime.now()), LocalDateTime.MAX.toLocalTime());

        List<TreePosterContent> treePosterContentList = this.lambdaQuery()
                .eq(TreePosterContent::getTreeId, queryDTO.getTreeId())
                .between(TreePosterContent::getCreatedTime, min, max)
                .list();
        for (TreePosterContent treePosterContent : treePosterContentList) {
            respDTO = new AppTreePosterContentRespDTO();
            BeanUtil.copyProperties(treePosterContent, respDTO);
            list.add(respDTO);
        }
        return list;
    }
}
