create table tb_app_user
(
    id           int auto_increment comment '主键'
        primary key,
    garden_id    int default 0 null comment '最新进入果园id',
    union_id     varchar(255)  null,
    tel          varchar(15)   null comment '手机号',
    name         varchar(32)   null comment '用户名',
    sex          int           null comment '性别-{0：女，1：男}',
    open_id      varchar(255)  null,
    icon         varchar(255)  null comment '机构id',
    app_id       varchar(255)  null,
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int default 0 null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '小程序用户';

create table tb_area
(
    id           int auto_increment comment '主键'
        primary key,
    garden_id    int           null comment '果园id',
    name         varchar(255)  null comment '区域名称',
    wkt          text          null comment '坐标',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int default 0 null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '区域';

create table tb_foster_record
(
    id               int auto_increment comment '主键'
        primary key,
    app_user_id      int           null comment '小程序用户id',
    garden_id        int default 0 null comment '果园id',
    tree_id          int           null comment '树id',
    birdseye_tree_id int default 0 null comment '飞鸟看园树id',
    status           int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id        int default 0 null comment '租户号',
    version          int default 1 null comment '乐观锁',
    is_deleted       int default 0 null comment '是否删除',
    created_by       varchar(32)   null comment '创建人',
    created_time     datetime      null comment '创建时间',
    updated_by       varchar(32)   null comment '更新人',
    updated_time     datetime      null comment '更新时间'
)
    comment '领养记录';

create table tb_garden
(
    id                 int auto_increment comment '主键'
        primary key,
    name               varchar(32)             null comment '果园名称',
    day_bg             varchar(255) default '' null comment '果园白天背景',
    night_bg           varchar(255) default '' null comment '果园夜晚背景',
    birdseye_garden_id int          default 0  null comment '飞鸟看园果园id',
    user_id            int                     null comment '用户id',
    base_map_url       varchar(255)            null comment '底图',
    qr_code            varchar(255)            null comment '二维码',
    cover_url1         varchar(255) default '' null comment '封面图片1',
    cover_url1_content text                    null comment '描述1',
    cover_url2         varchar(255) default '' null comment '封面图片2',
    cover_url2_content text                    null comment '描述2',
    cover_url3         varchar(255) default '' null comment '封面图片3',
    cover_url3_content text                    null comment '描述3',
    cover_url4         varchar(255) default '' null comment '封面图片4',
    cover_url4_content text                    null comment '描述4',
    status             int          default 1  null comment '状态-{0.不可用 1.可用}',
    tenant_id          int          default 0  null comment '租户号',
    version            int          default 1  null comment '乐观锁',
    is_deleted         int          default 0  null comment '是否删除',
    created_by         varchar(32)             null comment '创建人',
    created_time       datetime                null comment '创建时间',
    updated_by         varchar(32)             null comment '更新人',
    updated_time       datetime                null comment '更新时间'
)
    comment '果园';

create table tb_menu
(
    id           int auto_increment comment '主键'
        primary key,
    menu_name    varchar(32)   null comment '菜单名称',
    menu_code    varchar(32)   null comment '菜单编码',
    parent_id    int           null comment '父节点',
    is_admin     int default 0 null comment '0：嘉谷和医院的菜单，1：嘉谷的菜单',
    menu_sort    int           null comment '菜单排序',
    type         int           null comment '菜单类型-{0：父级菜单 1：菜单，2：权限}',
    permission   varchar(100)  null comment '权限',
    url          varchar(100)  null comment '前端页面路径',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '菜单表';

create table tb_poster_lib
(
    id           int auto_increment comment '主键'
        primary key,
    name         varchar(32)            not null comment '海报名称',
    url          varchar(255)           null comment '海报url',
    content      text                   null comment '悄悄话内容',
    start_time   varchar(20) default '' null comment '开始时间',
    end_time     varchar(20) default '' null comment '结束时间',
    status       int         default 1  null comment '状态-{0.不可用 1.可用}',
    tenant_id    int         default 0  null comment '租户号',
    version      int         default 1  null comment '乐观锁',
    is_deleted   int         default 0  null comment '是否删除',
    created_by   varchar(32)            null comment '创建人',
    created_time datetime               null comment '创建时间',
    updated_by   varchar(32)            null comment '更新人',
    updated_time datetime               null comment '更新时间'
)
    comment '海报库';

create table tb_role
(
    id           int auto_increment comment '主键'
        primary key,
    role_name    varchar(35)   not null comment '角色名称',
    role_code    varchar(50)   null comment '角色编码',
    is_admin     int default 0 null comment '管理员角色-{0：不是，1：是}',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int           null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '角色表';

create table tb_role_menu
(
    id           int auto_increment comment '主键'
        primary key,
    role_id      int           not null comment '角色id',
    menu_id      int           not null comment '菜单id',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '角色菜单关系表';

create table tb_tenant
(
    id           int auto_increment comment '主键'
        primary key,
    tenant_name  varchar(100)  null comment '租户名称',
    parent_id    int default 0 null comment '父级id',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time timestamp     null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time timestamp     null comment '更新时间'
)
    comment '系统租户表';

create table tb_tree
(
    id           int auto_increment comment '主键'
        primary key,
    garden_id    int           null comment '果园id',
    area_id      int           null comment '区域id',
    wkt          varchar(255)  null comment '坐标',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int default 0 null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '树';

create table tb_tree_image
(
    id           int auto_increment comment '主键'
        primary key,
    tree_id      varchar(255)  null comment '树id',
    url          varchar(255)  null comment '图片地址',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int default 0 null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '树照片';

create table tb_tree_poster_content
(
    id            int auto_increment comment '主键'
        primary key,
    poster_lib_id int default 0 null comment '海报库表主键id',
    poster_url    varchar(255)  null comment '海报url',
    content       varchar(255)  null comment '悄悄话内容',
    app_user_id   int           null comment '小程序用户id',
    tree_id       int           null comment '树id',
    status        int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id     int default 0 null comment '租户号',
    version       int default 1 null comment '乐观锁',
    is_deleted    int default 0 null comment '是否删除',
    created_by    varchar(32)   null comment '创建人',
    created_time  datetime      null comment '创建时间',
    updated_by    varchar(32)   null comment '更新人',
    updated_time  datetime      null comment '更新时间'
)
    comment '果树海报悄悄话';

create table tb_user
(
    id           int auto_increment comment '主键'
        primary key,
    username     varchar(32)   null comment '账号',
    password     varchar(100)  null comment '密码',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int           null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间',
    constraint username
        unique (username)
)
    comment '用户表';

create table tb_user_role
(
    id           int auto_increment comment '主键'
        primary key,
    user_id      int           not null comment '用户id',
    role_id      int           not null comment '角色id',
    status       int default 1 null comment '状态-{0.不可用 1.可用}',
    tenant_id    int           null comment '租户号',
    version      int default 1 null comment '乐观锁',
    is_deleted   int default 0 null comment '是否删除',
    created_by   varchar(32)   null comment '创建人',
    created_time datetime      null comment '创建时间',
    updated_by   varchar(32)   null comment '更新人',
    updated_time datetime      null comment '更新时间'
)
    comment '用户角色表';

create table tb_whisper
(
    id           int auto_increment comment '主键'
        primary key,
    content      varchar(255)           null comment '文案内容',
    start_time   varchar(20) default '' null comment '开始时间',
    end_time     varchar(20) default '' null comment '结束时间',
    status       int         default 1  null comment '状态-{0.不可用 1.可用}',
    tenant_id    int         default 0  null comment '租户号',
    version      int         default 1  null comment '乐观锁',
    is_deleted   int         default 0  null comment '是否删除',
    created_by   varchar(32)            null comment '创建人',
    created_time datetime               null comment '创建时间',
    updated_by   varchar(32)            null comment '更新人',
    updated_time datetime               null comment '更新时间'
)
    comment '悄悄话';

